.*: Assembler messages:
.*: Error: illegal operands `cv.slet t4,t2,3'
.*: Error: illegal operands `cv.sletu t4,t2,4'
.*: Error: illegal operands `cv.min t4,t2,13'
.*: Error: illegal operands `cv.minu t4,t2,7'
.*: Error: illegal operands `cv.max t4,t2,17'
.*: Error: illegal operands `cv.maxu t4,t2,30'
.*: Error: illegal operands `cv.clipr t4,t2,18'
.*: Error: illegal operands `cv.clipur t4,t2,29'
.*: Error: illegal operands `cv.addn t4,t2,24,4'
.*: Error: illegal operands `cv.addun t4,t2,6,4'
.*: Error: illegal operands `cv.addrn t6,t0,7,9'
.*: Error: illegal operands `cv.addurn t6,t0,18,14'
.*: Error: illegal operands `cv.addnr t6,t0,15'
.*: Error: illegal operands `cv.addunr t6,t0,24'
.*: Error: illegal operands `cv.addrnr t6,t0,3'
.*: Error: illegal operands `cv.addurnr t6,t0,2'
.*: Error: illegal operands `cv.subn t6,t0,1,6'
.*: Error: illegal operands `cv.subun t6,t0,8,24'
.*: Error: illegal operands `cv.subrn t6,t0,18,21'
.*: Error: illegal operands `cv.suburn t6,t0,25,3'
.*: Error: illegal operands `cv.subnr t6,t0,14'
.*: Error: illegal operands `cv.subunr t6,t0,7'
.*: Error: illegal operands `cv.subrnr t6,t0,18'
.*: Error: illegal operands `cv.suburnr t6,t0,26'
