.*: Assembler messages:
.*: Error: illegal operands `cv.subnr 10,t3,t6'
.*: Error: illegal operands `cv.addrnr t4,26,t6'
.*: Error: illegal operands `cv.subunr t6,t3,15'
.*: Error: instruction cv.clipu requires absolute expression
.*: Error: instruction cv.addn requires absolute expression
.*: Error: illegal operands `cv.clipu t0,t3,-10'
.*: Error: illegal operands `cv.clipu t0,t3,500'
.*: Error: illegal operands `cv.addn t0,t3,t6,-60'
.*: Error: illegal operands `cv.addn t0,t3,t6,302'
.*: Error: illegal operands `cv.clipu t0,t3,-1'
.*: Error: illegal operands `cv.clipu t0,t3,32'
.*: Error: illegal operands `cv.addn t0,t3,t6,-1'
.*: Error: illegal operands `cv.addn t0,t3,t6,32'
