.*: Assembler messages:
.*: Error: unrecognized opcode `cv.abs t4,t2', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.slet t4,t2,t6', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.sletu t4,t2,t6', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.min t4,t2,t6', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.minu t4,t2,t6', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.max t4,t2,t6', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.maxu t4,t2,t6', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.exths t4,t2', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.exthz t4,t2', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.extbs t4,t2', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.extbz t4,t2', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.clip t4,t2,5', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.clipu t4,t2,5', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.clipr t4,t2,t6', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.clipur t4,t2,t6', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.addn t4,t2,t0,4', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.addun t4,t2,t0,4', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.addrn t6,t0,t3,9', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.addurn t6,t0,t3,14', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.addnr t6,t0,t3', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.addunr t6,t0,t3', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.addrnr t6,t0,t3', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.addurnr t6,t0,t3', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.subn t6,t0,t3,6', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.subun t6,t0,t3,24', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.subrn t6,t0,t3,21', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.suburn t6,t0,t3,3', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.subnr t6,t0,t3', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.subunr t6,t0,t3', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.subrnr t6,t0,t3', extension `xcvalu' required
.*: Error: unrecognized opcode `cv.suburnr t6,t0,t3', extension `xcvalu' required
